RDFFormats.Store.AbstractStore

Package RDFFormats :: Module Store :: Class AbstractStore |
[show private | hide private]
[frames | no frames]

## Class AbstractStore

Known Subclasses:
  `FreeBusyRequest`, `Store`

    The interface employed by the RDFCalendar.Parsers classes.

Method Summary
| `add_contains(self, node, element)`
| `add_name(self, node, name)`
| `add_node(self, label, uriref)`
| `has_item(self, uriref)`

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net